==> xpojo-0.9.0-src.zip: ExcelPOJO Version 0.9.0/Samples/Sample1/src/some/TableInfo.java <==
package some;


import java.util.Comparator;
import java.util.List;
import java.util.TreeMap;

public class TableInfo {

	private TreeMap<String, ColumnInfo> columnInfoMap = new TreeMap<String, ColumnInfo>(new ComparatorString2Int()) ;		// e[uŗL̃Ji[
	private TreeMap<String, ColumnInfo> primaryKeyMap = new TreeMap<String, ColumnInfo>(new ComparatorString2Int()) ;		// vC}[L[i_L[ji[

	public String toString() {
		StringBuffer sBuff = new StringBuffer();
		sBuff.append( "[TableName=" + getTableName() + "]");
		sBuff.append( "[TableNameKnj=" + getTableNameKnj() + "]");
		sBuff.append( "[TableType=" + getTableType() + "]");

		return sBuff.toString();
	}

//	------------------------------< ϐݒ >
	private String tableName = "";
	private String tableNameKnj = "";
	private String tableType = "";

//	------------------------------< setter` >
	public void setTableName(String sVal){ this.tableName=sVal; }
	public void setTableNameKnj(String sVal){ this.tableNameKnj=sVal; }
	public void setTableType(String sVal){ this.tableType=sVal; }

//	------------------------------< getter` >
	public String getTableName(){ return this.tableName; }
	public String getTableNameKnj(){ return this.tableNameKnj; }
	public String getTableType(){ return this.tableType; }

	public TreeMap<String, ColumnInfo> getPrimaryKeyMap() {
		return primaryKeyMap;
	}
	public TreeMap<String, ColumnInfo> getColumnMap() {
		return columnInfoMap ;
	}

	public void setColumnList(List<ColumnInfo> columnList) {
		columnInfoMap.clear();
		for (ColumnInfo columnInfo : columnList) {
			columnInfoMap.put(String.valueOf(columnInfo.getColumnId()), columnInfo);

			// vC}[L[i_L[j̏ꍇ
			if (columnInfo.getPrimaryKeyNo() > 0) {
				primaryKeyMap.put(String.valueOf(columnInfo.getPrimaryKeyNo()), columnInfo);
			}
		}
	}

	public ColumnInfo getColumn(String columnName) {
		ColumnInfo retCol = null ;

		for (String key : columnInfoMap.keySet()) {
			ColumnInfo column = columnInfoMap.get(key);

			if (column.getColumnName().equalsIgnoreCase(columnName)) {
				retCol = column;
				break ;
			}
		}
		return retCol;
	}

	private class ComparatorString2Int implements Comparator<Object> {

		public ComparatorString2Int() {
			super();
		}

		public int compare(Object arg0, Object arg1) {
			String sArg0 = (String)arg0;
			String sArg1 = (String)arg1;

			int nArg0 = Integer.parseInt((String)arg0);
			int nArg1 = Integer.parseInt((String)arg1);

			return (nArg0 - nArg1);
		}

}

}

==> xpojo-1.1.2-src.zip: ExcelPOJO Version 1.1.2/Samples/Sample1/src/some/TableInfo.java <==
package some;


import java.util.Comparator;
import java.util.List;
import java.util.TreeMap;

public class TableInfo {

	private TreeMap<String, ColumnInfo> columnInfoMap = new TreeMap<String, ColumnInfo>(new ComparatorString2Int()) ;		// e[uŗL̃Ji[
	private TreeMap<String, ColumnInfo> primaryKeyMap = new TreeMap<String, ColumnInfo>(new ComparatorString2Int()) ;		// vC}[L[i_L[ji[

	public String toString() {
		StringBuffer sBuff = new StringBuffer();
		sBuff.append( "[TableName=" + getTableName() + "]");
		sBuff.append( "[TableNameKnj=" + getTableNameKnj() + "]");
		sBuff.append( "[TableType=" + getTableType() + "]");

		return sBuff.toString();
	}

//	------------------------------< ϐݒ >
	private String tableName = "";
	private String tableNameKnj = "";
	private String tableType = "";

//	------------------------------< setter` >
	public void setTableName(String sVal){ this.tableName=sVal; }
	public void setTableNameKnj(String sVal){ this.tableNameKnj=sVal; }
	public void setTableType(String sVal){ this.tableType=sVal; }

//	------------------------------< getter` >
	public String getTableName(){ return this.tableName; }
	public String getTableNameKnj(){ return this.tableNameKnj; }
	public String getTableType(){ return this.tableType; }

	public TreeMap<String, ColumnInfo> getPrimaryKeyMap() {
		return primaryKeyMap;
	}
	public TreeMap<String, ColumnInfo> getColumnMap() {
		return columnInfoMap ;
	}

	private List<ColumnInfo> columnList;
	public List<ColumnInfo> getColumnList() {
		return this.columnList;
	}
	public void setColumnList(List<ColumnInfo> columnList) {
		this.columnList = columnList;
		columnInfoMap.clear();
		for (ColumnInfo columnInfo : columnList) {
			columnInfoMap.put(String.valueOf(columnInfo.getColumnId()), columnInfo);

			// vC}[L[i_L[j̏ꍇ
			if (columnInfo.getPrimaryKeyNo() > 0) {
				primaryKeyMap.put(String.valueOf(columnInfo.getPrimaryKeyNo()), columnInfo);
			}
		}
	}

	public ColumnInfo getColumn(String columnName) {
		ColumnInfo retCol = null ;

		for (String key : columnInfoMap.keySet()) {
			ColumnInfo column = columnInfoMap.get(key);

			if (column.getColumnName().equalsIgnoreCase(columnName)) {
				retCol = column;
				break ;
			}
		}
		return retCol;
	}

	private class ComparatorString2Int implements Comparator<Object> {

		public ComparatorString2Int() {
			super();
		}

		public int compare(Object arg0, Object arg1) {
			String sArg0 = (String)arg0;
			String sArg1 = (String)arg1;

			int nArg0 = Integer.parseInt((String)arg0);
			int nArg1 = Integer.parseInt((String)arg1);

			return (nArg0 - nArg1);
		}

}

}
